<template>
  <div class="device-detail-container">
    <a-page-header
      title="设备预测性维护详情"
      :sub-title="deviceInfo.deviceName"
      @back="() => $router.go(-1)"
    />

    <a-row :gutter="16" class="mt-4">
      <!-- 设备基本信息 -->
      <a-col :span="8">
        <a-card title="设备基本信息" class="mb-4" :style="{ height: '440px' }">
          <a-descriptions bordered :column="1">
            <a-descriptions-item label="设备名称">{{ deviceInfo.deviceName }}</a-descriptions-item>
            <a-descriptions-item label="设备类型">{{ deviceInfo.deviceType }}</a-descriptions-item>
            <a-descriptions-item label="设备编号">{{ deviceInfo.deviceId }}</a-descriptions-item>
            <a-descriptions-item label="安装日期">{{ deviceInfo.installDate }}</a-descriptions-item>
            <a-descriptions-item label="使用年限">{{ deviceInfo.serviceLife }}年</a-descriptions-item>
            <a-descriptions-item label="当前状态">
              <a-tag :color="deviceInfo.statusColor">{{ deviceInfo.status }}</a-tag>
            </a-descriptions-item>
          </a-descriptions>
        </a-card>
      </a-col>

      <!-- 设备健康状态与维护建议 -->
      <a-col :span="16">
        <a-card title="设备健康状态与维护建议" class="mb-4" :style="{ height: '440px' }">
          <a-row :gutter="16">
            <a-col :span="8">
              <a-statistic
                title="整体健康度"
                :value="healthData.overallHealth"
                :precision="0"
                suffix="%"
                :value-style="{ color: healthData.healthColor }"
              />
            </a-col>
            <a-col :span="8">
              <a-statistic
                title="预测剩余寿命"
                :value="healthData.predictedLife"
                suffix="天"
              />
            </a-col>
            <a-col :span="8">
              <a-statistic
                title="故障风险等级"
                :value="healthData.riskLevel"
                :value-style="{ color: healthData.riskColor }"
              />
            </a-col>
          </a-row>
          <div class="mt-4">
            <a-progress
              :percent="healthData.overallHealth"
              :stroke-color="healthData.healthColor"
              :show-info="false"
            />
          </div>
          <a-divider orientation="left">预测性维护建议</a-divider>
          <a-table
            :columns="maintenanceColumns"
            :data-source="maintenanceData"
            :pagination="false"
            size="small"
          >
            <template #urgency="{ text }">
              <a-tag :color="getUrgencyColor(text)">{{ text }}</a-tag>
            </template>
            <template #action="{ record }">
              <a-button type="link" size="small" @click="handleMaintenance(record)">处理</a-button>
            </template>
          </a-table>
        </a-card>
      </a-col>
    </a-row>

    <!-- 实时数据趋势图 -->
    <a-card title="实时数据趋势图" class="mb-4">
      <a-row :gutter="16">
        <a-col :span="8">
          <div id="temperatureChart" style="height: 300px;"></div>
        </a-col>
        <a-col :span="8">
          <div id="vibrationChart" style="height: 300px;"></div>
        </a-col>
        <a-col :span="8">
          <div id="currentChart" style="height: 300px;"></div>
        </a-col>
      </a-row>
    </a-card>
    <a-row :gutter="16">
      <!-- 部件寿命预测 -->
      <a-col :span="12">
        <a-card title="部件寿命预测" class="mb-4">
          <a-table
            :columns="sparePartColumns"
            :data-source="sparePartData"
            :pagination="false"
            size="small"
          >
            <template #status="{ text }">
              <a-tag :color="getStatusColor(text)">{{ text }}</a-tag>
            </template>
          </a-table>
        </a-card>
      </a-col>

      <!-- 历史维护记录 -->
      <a-col :span="12">
        <a-card title="历史维护记录" class="mb-4">
          <a-timeline>
            <a-timeline-item v-for="item in historyData" :key="item.id" :color="item.color">
              {{ item.date }} - {{ item.type }}: {{ item.description }}
            </a-timeline-item>
          </a-timeline>
        </a-card>
      </a-col>
    </a-row>

  </div>
</template>

<script lang="ts">
import { defineComponent, reactive, onMounted, onUnmounted } from 'vue';
import * as echarts from 'echarts';

export default defineComponent({
  name: 'DeviceDetail',
  setup() {
    // 模拟数据
    const deviceInfo = reactive({
      deviceName: 'CNC加工中心',
      deviceType: '数控机床',
      deviceId: 'CNC-2023-001',
      installDate: '2023-01-15',
      serviceLife: 10,
      status: '运行中',
      statusColor: '#52c41a'
    });

    const healthData = reactive({
      overallHealth: 85,
      healthColor: '#52c41a',
      predictedLife: 1825,
      riskLevel: '中风险',
      riskColor: '#faad14'
    });

    const maintenanceColumns = [
      {
        title: '维护类型',
        dataIndex: 'type',
        key: 'type'
      },
      {
        title: '维护内容',
        dataIndex: 'content',
        key: 'content'
      },
      {
        title: '建议时间',
        dataIndex: 'suggestedTime',
        key: 'suggestedTime'
      },

      {
        title: '紧急程度',
        dataIndex: 'urgency',
        key: 'urgency',
        slots: { customRender: 'urgency' }
      },
      {
        title: '操作',
        key: 'action',
        slots: { customRender: 'action' }
      }
    ];

    const maintenanceData = reactive([
      {
        key: '1',
        type: '润滑保养',
        content: '主轴润滑系统需要更换润滑油',
        suggestedTime: '2024-03-15',
        urgency: '中等'
      },
      {
        key: '2',
        type: '校准检查',
        content: 'X轴导轨需要重新校准',
        suggestedTime: '2024-04-01',
        urgency: '高'
      }
    ]);

    const getUrgencyColor = (urgency: string) => {
      switch (urgency) {
        case '高':
          return 'red';
        case '中等':
          return 'orange';
        case '低':
          return 'green';
        default:
          return 'default';
      }
    };

    const sparePartColumns = [
      {
        title: '部件名称',
        dataIndex: 'name',
        key: 'name'
      },
      {
        title: '当前寿命',
        dataIndex: 'currentLife',
        key: 'currentLife',
        customRender: ({ text }: { text: number }) => `${text}天`
      },
      {
        title: '预测剩余寿命',
        dataIndex: 'remainingLife',
        key: 'remainingLife',
        customRender: ({ text }: { text: number }) => `${text}天`
      },
      {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        slots: { customRender: 'status' }
      }
    ];

    const sparePartData = reactive([
      {
        key: '1',
        name: '主轴轴承',
        currentLife: 365,
        remainingLife: 120,
        status: '良好'
      },
      {
        key: '2',
        name: 'X轴导轨',
        currentLife: 730,
        remainingLife: 30,
        status: '预警'
      },
      {
        key: '3',
        name: '刀具夹头',
        currentLife: 180,
        remainingLife: 90,
        status: '良好'
      }
    ]);

    const historyData = reactive([
      {
        id: '1',
        date: '2024-01-10',
        type: '定期保养',
        description: '完成季度保养，更换润滑油和过滤器',
        color: 'green'
      },
      {
        id: '2',
        date: '2023-10-15',
        type: '故障维修',
        description: '修复主轴电机过热问题',
        color: 'red'
      },
      {
        id: '3',
        date: '2023-07-20',
        type: '定期保养',
        description: '完成半年保养，校准各轴精度',
        color: 'green'
      }
    ]);

    const getStatusColor = (status: string) => {
      switch (status) {
        case '良好':
          return '#52c41a';
        case '预警':
          return '#faad14';
        case '危险':
          return '#f5222d';
        default:
          return '#d9d9d9';
      }
    };

    const handleMaintenance = (record: any) => {
      console.log('处理维护建议:', record);
      // 实际项目中这里会调用API处理维护建议
    };

    return {
      deviceInfo,
      healthData,
      maintenanceColumns,
      maintenanceData,
      sparePartColumns,
      sparePartData,
      historyData,
      getStatusColor,
      getUrgencyColor,
      handleMaintenance
    };
  },

  mounted() {
    // 初始化图表
    const initChart = (chartId: string, title: string, chartData: any[], unit: string, baseValue: number, fluctuation: number) => {
      const chart = echarts.init(document.getElementById(chartId));

      // 预生成60个数据点
      for (let i = 0; i < 60; i++) {
        const now = new Date(Date.now() - (60 - 1 - i) * 5000); // 5秒间隔
        const value = +(Math.random() * fluctuation + baseValue - fluctuation / 2).toFixed(2);
        chartData.push({
          time: `${now.getHours()}:${now.getMinutes()}:${now.getSeconds()}`,
          value: value
        });
      }

      const updateChart = () => {
        // 生成新的数据点
        const now = new Date();
        const time = `${now.getHours()}:${now.getMinutes()}:${now.getSeconds()}`;
        const newValue = +(Math.random() * fluctuation + baseValue - fluctuation / 2).toFixed(2);

        // 添加新数据点，最多保留60个点（5分钟数据）
        chartData.push({
          time,
          value: newValue
        });
        if (chartData.length > 60) {
          chartData.shift();
        }

        const option = {
          title: {
            text: title,
            left: 'center'
          },
          tooltip: {
            trigger: 'axis',
            formatter: (params: any) => {
              return `${params[0].axisValueLabel}<br/>${params[0].marker} ${params[0].seriesName}: ${params[0].data}${unit}`;
            }
          },
          xAxis: {
            type: 'category',
            data: chartData.map(item => item.time)
          },
          yAxis: {
            type: 'value',
            axisLabel: {
              formatter: (value: number) => {
                return `${value}${unit}`;
              }
            }
          },
          series: [
            {
              data: chartData.map(item => parseFloat(item.value)),
              type: 'line',
              smooth: true,
              lineStyle: {
                width: 2,
                color: chartId === 'temperatureChart' ? '#5470C6' : chartId === 'vibrationChart' ? '#91CC75' : '#FAC858' // 根据图表ID设置颜色
              },
              areaStyle: {
                opacity: 0.8,
                color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                  {
                    offset: 0,
                    color: chartId === 'temperatureChart' ? 'rgba(84,112,198,0.3)' : chartId === 'vibrationChart' ? 'rgba(145,204,117,0.3)' : 'rgba(250,200,88,0.3)'
                  },
                  {
                    offset: 1,
                    color: chartId === 'temperatureChart' ? 'rgba(84,112,198,0)' : chartId === 'vibrationChart' ? 'rgba(145,204,117,0)' : 'rgba(250,200,88,0)'
                  }
                ])
              },
            }
          ]
        };
        chart.setOption(option);
      };

      // 初始渲染
      updateChart();

      // 每5秒更新一次数据
      const intervalId = setInterval(updateChart, 5000);

      window.addEventListener('resize', () => {
        chart.resize();
      });
            onUnmounted(() => {
        clearInterval(intervalId);
      });

    };

    const temperatureData: any[] = reactive([]);
    const vibrationData: any[] = reactive([]);
    const currentData: any[] = reactive([]);

    initChart('temperatureChart', '温度趋势', temperatureData, '°C', 60, 5);
    initChart('vibrationChart', '振动趋势', vibrationData, 'mm/s', 10, 2);
    initChart('currentChart', '电流趋势', currentData, 'A', 50, 10);
  }

});
</script>

<style scoped>
.device-detail-container {
  padding: 16px;
  background: #f0f2f5;
}
</style>
